@@ -4,7 +4,7 @@ WORK_DIR=$PWD
 
 DEBIAN_DIR=${WORK_DIR}/debian
 
-INCLUDES_DIR=${DEBIAN_DIR}/includes/pwiz
+INCLUDES_DIR=${DEBIAN_DIR}/includes/proteowizard
 
 rm -rf ${INCLUDES_DIR}
 
